@@ -1,4 +1,4 @@
-// SPDX-FileCopyrightText: 2020-2023 Tobias Leupold <tl at stonemx dot de>
+// SPDX-FileCopyrightText: 2020-2024 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -37,11 +37,7 @@
 #include <KXMLGUIFactory>
 
 // Qt includes
-#include <QMenuBar>
-#include <QAction>
 #include <QDockWidget>
-#include <QGuiApplication>
-#include <QScreen>
 #include <QApplication>
 #include <QDebug>
 #include <QFileDialog>
@@ -49,10 +45,7 @@
 #include <QFile>
 #include <QTimer>
 #include <QMessageBox>
-#include <QCloseEvent>
-#include <QAbstractButton>
 #include <QVBoxLayout>
-#include <QLoggingCategory>
 
 // C++ includes
 #include <functional>
@@ -93,14 +86,14 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
     auto *addFilesAction = actionCollection()->addAction(QStringLiteral("addFiles"));
     addFilesAction->setText(i18n("Add images and/or GPX tracks"));
     addFilesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
-    actionCollection()->setDefaultShortcut(addFilesAction, QKeySequence(tr("Ctrl+F")));
+    actionCollection()->setDefaultShortcut(addFilesAction, QKeySequence(Qt::CTRL | Qt::Key_F));
     connect(addFilesAction, &QAction::triggered,
             this, std::bind(&MainWindow::addFiles, this, QStringList()));
 
     auto *addDirectoryAction = actionCollection()->addAction(QStringLiteral("addDirectory"));
     addDirectoryAction->setText(i18n("Add all images and tracks from a folder"));
     addDirectoryAction->setIcon(QIcon::fromTheme(QStringLiteral("archive-insert-directory")));
-    actionCollection()->setDefaultShortcut(addDirectoryAction, QKeySequence(tr("Ctrl+D")));
+    actionCollection()->setDefaultShortcut(addDirectoryAction, QKeySequence(Qt::CTRL | Qt::Key_D));
     connect(addDirectoryAction, &QAction::triggered,
             this, std::bind(&MainWindow::addDirectory, this, QString()));
 
@@ -128,24 +121,41 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
 
     auto *removeEverything = actionCollection()->addAction(QStringLiteral("removeEverything"));
     removeEverything->setText(i18n("All images and tracks (reset)"));
+    actionCollection()->setDefaultShortcut(removeEverything, QKeySequence(Qt::CTRL | Qt::Key_R));
     connect(removeEverything, &QAction::triggered, this, &MainWindow::removeEverything);
 
     // "File" menu again
 
     auto *searchMatchesAction = actionCollection()->addAction(QStringLiteral("searchMatches"));
-    searchMatchesAction->setText(i18n("Assign images to GPS data"));
+    searchMatchesAction->setText(i18n("Correlate images with GPS data (search matches)"));
     searchMatchesAction->setIcon(QIcon::fromTheme(QStringLiteral("crosshairs")));
-    actionCollection()->setDefaultShortcut(searchMatchesAction, QKeySequence(tr("Ctrl+M")));
+    actionCollection()->setDefaultShortcut(searchMatchesAction, QKeySequence(Qt::CTRL | Qt::Key_M));
     connect(searchMatchesAction, &QAction::triggered,
-            [this]
+            this, [this]
             {
                 triggerCompleteAutomaticMatching(m_settings->defaultMatchingMode());
             });
 
+    // "Current selection" submenu
+
+    auto *assignToMapCenter = actionCollection()->addAction(QStringLiteral("assignToMapCenter"));
+    assignToMapCenter->setText(i18n("(Re-)Assign to map center"));
+    assignToMapCenter->setIcon(QIcon::fromTheme(QStringLiteral("crosshairs")));
+    actionCollection()->setDefaultShortcut(assignToMapCenter, QKeySequence(Qt::CTRL | Qt::Key_C));
+    connect(assignToMapCenter, &QAction::triggered, this, &MainWindow::assignSelectionToMapCenter);
+
+    m_selectNextUntagged = actionCollection()->addAction(QStringLiteral("selectNextUntagged"));
+    m_selectNextUntagged->setText(i18n("Automatically select next untagged image"));
+    m_selectNextUntagged->setCheckable(true);
+    m_selectNextUntagged->setChecked(m_settings->selectNextUntagged());
+    connect(m_selectNextUntagged, &QAction::toggled, m_settings, &Settings::saveSelectNextUntagged);
+
+    // "File" menu again
+
     auto *saveChangesAction = actionCollection()->addAction(QStringLiteral("saveChanges"));
     saveChangesAction->setText(i18n("Save changed images"));
     saveChangesAction->setIcon(QIcon::fromTheme(QStringLiteral("document-save-all")));
-    actionCollection()->setDefaultShortcut(saveChangesAction, QKeySequence(tr("Ctrl+S")));
+    actionCollection()->setDefaultShortcut(saveChangesAction, QKeySequence(Qt::CTRL | Qt::Key_S));
     connect(saveChangesAction, &QAction::triggered, this, &MainWindow::saveAllChanges);
 
     KStandardAction::quit(this, &QWidget::close, actionCollection());
@@ -206,7 +216,7 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
     // Map
 
     m_mapWidget = m_sharedObjects->mapWidget();
-    m_mapCenterInfo = new MapCenterInfo(m_sharedObjects);
+    m_mapCenterInfo = new MapCenterInfo(m_sharedObjects, m_mapWidget->mapCenterMenu());
     connect(m_mapWidget, &MapWidget::mapMoved, m_mapCenterInfo, &MapCenterInfo::mapMoved);
 
     auto *mapWrapper = new QWidget;
@@ -218,6 +228,8 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
 
     connect(m_mapWidget, &MapWidget::imagesDropped, this, &MainWindow::imagesDropped);
     connect(m_mapWidget, &MapWidget::requestLoadGpx, this, &MainWindow::addGpx);
+    connect(m_mapWidget, &MapWidget::requestAddBookmark,
+            m_bookmarksWidget, &BookmarksWidget::requestAddBookmark);
 
     // Images lists
 
@@ -246,13 +258,14 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
 
     m_tracksDock = createDockWidget(i18n("Tracks"), tracksWrapper, QStringLiteral("tracksDock"));
 
-    // Initialize/Restore the dock widget arrangement
+    // Ensure a decent dock layout if none has been saved before
     if (! restoreState(m_settings->mainWindowState())) {
         setDefaultDockArrangement();
-    } else {
-        m_unAssignedImagesDock->setVisible(m_settings->splitImagesList());
     }
 
+    // Be sure to hide the "assigned" images list if the list is not splitted
+    m_unAssignedImagesDock->setVisible(m_settings->splitImagesList());
+
     // Restore the map's settings
     m_mapWidget->restoreSettings();
 
@@ -263,7 +276,7 @@ MainWindow::MainWindow(SharedObjects *sharedObjects)
             this, &MainWindow::notAllElevationsPresent);
 
     // Check if we could setup the timezone detection properly
-    QTimer::singleShot(0, [this]
+    QTimer::singleShot(0, this, [this]
     {
         // We do this in a QTimer singleShot so that the main window
         // will be already visible if this warning should be displayed
@@ -313,20 +326,22 @@ QDockWidget *MainWindow::createImagesDock(KGeoTag::ImagesListType type, const QS
     return createDockWidget(title, list, dockId);
 }
 
+ImagesListView *MainWindow::imagesListView(QDockWidget *dock) const
+{
+    return qobject_cast<ImagesListView *>(dock->widget());
+}
+
 void MainWindow::updateImagesListsMode()
 {
     if (m_settings->splitImagesList()) {
         m_assignedOrAllImagesDock->setWindowTitle(i18n("Assigned images"));
-        qobject_cast<ImagesListView *>(
-            m_assignedOrAllImagesDock->widget())->setListType(KGeoTag::AssignedImages);
+        imagesListView(m_assignedOrAllImagesDock)->setListType(KGeoTag::AssignedImages);
         m_unAssignedImagesDock->show();
-        qobject_cast<ImagesListView *>(
-            m_unAssignedImagesDock->widget())->setListType(KGeoTag::UnAssignedImages);
+        imagesListView(m_unAssignedImagesDock)->setListType(KGeoTag::UnAssignedImages);
         m_imagesModel->setSplitImagesList(true);
     } else {
         m_assignedOrAllImagesDock->setWindowTitle(i18n("Images"));
-        qobject_cast<ImagesListView *>(
-            m_assignedOrAllImagesDock->widget())->setListType(KGeoTag::AllImages);
+        imagesListView(m_assignedOrAllImagesDock)->setListType(KGeoTag::AllImages);
         m_unAssignedImagesDock->hide();
         m_imagesModel->setSplitImagesList(false);
     }
@@ -347,6 +362,11 @@ void MainWindow::setDefaultDockArrangement()
     for (auto *dock : allDocks) {
         dock->setFloating(false);
         addDockWidget(Qt::TopDockWidgetArea, dock);
+
+        // It's actually possible to close a floating dock using keyboard shortcuts (when it
+        // shouldn't be possible, because QDockWidget::DockWidgetClosable is not set). To be sure
+        // to re-show such a closed dock, we explicitely show it here:
+        dock->show();
     }
 
     for (int i = 1; i < allDocks.count(); i++) {
@@ -389,27 +409,22 @@ QDockWidget *MainWindow::createDockWidget(const QString &title, QWidget *widget,
     return dock;
 }
 
-void MainWindow::closeEvent(QCloseEvent *event)
+bool MainWindow::queryClose()
 {
-    if (! m_imagesModel->imagesWithPendingChanges().isEmpty()) {
-        if (QMessageBox::question(this, i18n("Close KGeoTag"),
-            i18n("<p>There are pending changes to images that haven't been saved yet. All changes "
-                 "will be discarded if KGeoTag is closed now.</p>"
-                 "<p>Do you want to close the program anyway?</p>"),
-            QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No) {
+    if (! m_imagesModel->imagesWithPendingChanges().isEmpty()
+        && QMessageBox::question(this, i18n("Close KGeoTag"),
+               i18n("<p>There are pending changes to images that haven't been saved yet. All "
+                    "changes will be discarded if KGeoTag is closed now.</p>"
+                    "<p>Do you want to close the program anyway?</p>"),
+               QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::No) {
 
-            event->ignore();
-            return;
-        }
+        return false;
     }
 
-    m_settings->saveMainWindowState(saveState());
-
     m_mapWidget->saveSettings();
-
     m_settings->saveBookmarks(m_bookmarksWidget->bookmarks());
 
-    QApplication::quit();
+    return true;
 }
 
 void MainWindow::addPathsFromCommandLine(QStringList &paths)
@@ -930,7 +945,7 @@ void MainWindow::imagesDropped(const QVector<QString> &paths)
     }
 
     if (m_settings->splitImagesList()) {
-        qobject_cast<ImagesListView *>(m_assignedOrAllImagesDock->widget())->highlightImage(index);
+        imagesListView(m_assignedOrAllImagesDock)->highlightImage(index);
     }
 }
 
@@ -953,7 +968,9 @@ void MainWindow::assignManually(ImagesListView *list)
     }
 
     CoordinatesDialog dialog(CoordinatesDialog::Mode::EditCoordinates,
-                             m_settings->lookupElevationAutomatically(), Coordinates(), label);
+                             m_settings->lookupElevationAutomatically(),
+                             m_settings->latBeforeLon(), m_settings->coordinatesFlavor(),
+                             Coordinates(), label);
     if (! dialog.exec()) {
         return;
     }
@@ -985,6 +1002,7 @@ void MainWindow::editCoordinates(ImagesListView *list)
     }
 
     CoordinatesDialog dialog(CoordinatesDialog::Mode::EditCoordinates, false,
+                             m_settings->latBeforeLon(), m_settings->coordinatesFlavor(),
                              identicalCoordinates ? coordinates : Coordinates(),
                              label);
     if (! dialog.exec()) {
@@ -1008,7 +1026,7 @@ void MainWindow::assignTo(const QVector<QString> &paths, const Coordinates &coor
     }
 
     if (m_settings->splitImagesList()) {
-        qobject_cast<ImagesListView *>(m_assignedOrAllImagesDock->widget())->highlightImage(
+        imagesListView(m_assignedOrAllImagesDock)->highlightImage(
             m_imagesModel->indexFor(paths.last()));
     }
 }
@@ -1752,3 +1770,34 @@ void MainWindow::findClosestTrackPoint(const QString &path)
         point.second.toTimeZone(m_fixDriftWidget->imagesTimeZone()));
     m_mapWidget->blockSignals(false);
 }
+
+void MainWindow::assignSelectionToMapCenter()
+{
+    auto *assignedOrAllImages = imagesListView(m_assignedOrAllImagesDock);
+    auto *unAssignedImages = imagesListView(m_unAssignedImagesDock);
+
+    QVector<QString> selection;
+    selection += assignedOrAllImages->selectedPaths();
+    if (m_settings->splitImagesList()) {
+        selection += unAssignedImages->selectedPaths();
+    }
+
+    if (selection.isEmpty()) {
+        QMessageBox::information(this, i18n("Assign selection"),
+                                 i18n("Please select one or more images"));
+        return;
+    }
+
+    assignTo(selection, m_mapWidget->currentCenter());
+
+    if (m_selectNextUntagged->isChecked()) {
+        if (m_settings->splitImagesList()) {
+            assignedOrAllImages->clearSelection();
+            unAssignedImages->selectFirstUnassigned();
+        } else {
+            assignedOrAllImages->selectFirstUnassigned();
+        }
+    } else {
+        assignedOrAllImages->highlightImage(m_imagesModel->indexFor(selection.last()));
+    }
+}
