@@ -1,4 +1,4 @@
-//* SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
+//* SPDX-FileCopyrightText: 2020-2024 Tobias Leupold <tl at stonemx dot de>
 //
 // SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 
@@ -23,7 +23,6 @@ class Settings : public QObject
 public:
     explicit Settings(QObject *parent);
 
-    void saveMainWindowState(const QByteArray &data);
     QByteArray mainWindowState() const;
 
     void saveShowCrosshairs(bool state);
@@ -92,8 +91,19 @@ public:
     void saveDefaultMatchingMode(KGeoTag::SearchType mode);
     KGeoTag::SearchType defaultMatchingMode() const;
 
+    void saveSelectNextUntagged(bool state);
+    bool selectNextUntagged() const;
+
+    void saveLatBeforeLon(bool state);
+    bool latBeforeLon() const;
+
+    void saveCoordinatesFlavor(KGeoTag::CoordinatesFlavor flavor);
+    KGeoTag::CoordinatesFlavor coordinatesFlavor() const;
+
 private: // Variables
     KSharedConfig::Ptr m_config;
+    bool m_latBeforeLon = false;
+    KGeoTag::CoordinatesFlavor m_coordinatesFlavor = KGeoTag::DecimalDegrees;
 
 };
 
